@@ -5,13 +5,14 @@ from fastapi import HTTPException, status
 from fastapi.param_functions import Depends
 from datetime import timedelta, datetime
 from fastapi.security.oauth2 import SecurityScopes
-from config import ENVIRONMENT, SECRET_KEY, ALGORITHM, BASEURL
+# from config.config import ENVIRONMENT, config.SECRET_KEY, ALGORITHM, BASEURL
+from config import config
 
 import jwt
 
 
 oauth2_scheme = OAuth2PasswordBearer(
-    tokenUrl=BASEURL+"crmv2/main_auth/auth/login"
+    tokenUrl=config.BASE_URL+"crmv2/main_auth/auth/login"
 )
 
 CREDENTIALS_EXCEPTION = HTTPException(
@@ -26,7 +27,8 @@ ROLE_EXCPETION = HTTPException(
     headers={"WWW-Authenticate": "Bearer"},
 )
 
-ACCESS_TOKEN_EXPIRE_MINUTES = 15
+# ambil dari setting config
+# ACCESS_TOKEN_EXPIRE_MINUTES = 10
 
 
 # =============================class=============================
@@ -61,21 +63,20 @@ class JwtToken(BaseModel):
 async def mytoken(token: str = Depends(oauth2_scheme)):
     return token
 
-async def create_access_token(data: JwtToken, expires_delta: int, ALGORITHM='HS256'):
+async def create_access_token(data: JwtToken, expires_delta: int):
     if expires_delta:
         expire = datetime.utcnow() + timedelta(minutes=expires_delta)
     else:
-        expire = datetime.utcnow() + timedelta(minutes=1)
+        expire = datetime.utcnow() + timedelta(minutes=15)
     data.exp = expire
-    encoded_jwt = jwt.encode(data.dict(), SECRET_KEY, ALGORITHM)
+    encoded_jwt = jwt.encode(data.dict(), config.SECRET_KEY, config.ALGORITHM)
 
     return encoded_jwt
 
 async def get_current_user(security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)):
     try:
         # decode token and extract username and expires data
-        idxSecret = len(security_scopes.scopes)-1
-        payload = jwt.decode(token, SECRET_KEY, algorithms=['HS256'])
+        payload = jwt.decode(token, config.SECRET_KEY, algorithms=config.ALGORITHM)
         data_token = JwtToken()
         data_token.name = payload.get("name")
         data_token.username = payload.get("username")
@@ -99,9 +100,9 @@ async def get_current_user(security_scopes: SecurityScopes, token: str = Depends
         raise CREDENTIALS_EXCEPTION
     return data_token
 
-async def create_refresh_token(response, token, ALGORITHM='HS256'):
+async def create_refresh_token(response, token):
     try:
-        payload = jwt.decode(token, SECRET_KEY, algorithms=[ALGORITHM])
+        payload = jwt.decode(token, config.SECRET_KEY, algorithms=config.ALGORITHM)
         data_token = JwtToken()
         data_token.name = payload.get("name")
         data_token.username = payload.get("username")
@@ -118,7 +119,7 @@ async def create_refresh_token(response, token, ALGORITHM='HS256'):
         if datetime.utcfromtimestamp(payload.get("exp")) > datetime.utcnow():
             # cek username masih ada atau tidak
             # if(await GetUserOr404ByUsername(payload.get("username"))):
-            access_token = await create_access_token(data_token, 15, SECRET_KEY)
+            access_token = await create_access_token(data_token, config.ACCESS_TOKEN_EXPIRE_MINUTES)
             # print(access_token)
             btoken = "Bearer " + str(access_token)
             response.headers["Authorization"] = btoken
@@ -130,7 +131,8 @@ async def create_refresh_token(response, token, ALGORITHM='HS256'):
 
 async def get_config():
     return {
-        'env' : ENVIRONMENT,
-        'alg' : ALGORITHM,
-        'url' : BASEURL
+        'env' : config.ENVIRONMENT,
+        'alg' : config.ALGORITHM,
+        'url' : config.BASE_URL,
+        'host': config.MGDB_HOST
     }
